Module: Castle::Session
- Defined in:
- lib/castle/session.rb
Overview
this module uses the Connection object and provides start method for persistent connection usage when there is a need of sending multiple requests at once
Class Method Summary collapse
Class Method Details
.call(&block) ⇒ Object
9 10 11 12 13 |
# File 'lib/castle/session.rb', line 9 def call(&block) return unless block Castle::Core::GetConnection.call.start(&block) end |